﻿// <copyright company="PEER Group GmbH">
//    Copyright (c) PEER Group GmbH. All rights reserved.
// </copyright>

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Interactivity;

namespace fieldsBinding
{

	public class XamDataGridExpansionBehaviour : Behavior<MainWindow>
	{
		#region Override Methods
		/// <summary>
		/// Called after the behavior is attached to an AssociatedObject.
		/// </summary>
		/// <remarks>Override this to hook up functionality to the AssociatedObject.</remarks>
		protected override void OnAttached()
		{
			base.OnAttached();
			AssociatedObject.Initialized += AssociatedObject_Initialized;
		}

		/// <summary>
		/// Called when the behavior is being detached from its AssociatedObject, but before it has actually occurred.
		/// </summary>
		/// <remarks>Override this to unhook functionality from the AssociatedObject.</remarks>
		protected override void OnDetaching()
		{
			base.OnDetaching();
			AssociatedObject.Initialized -= AssociatedObject_Initialized;
			AssociatedObject.ExpandAllButton.Click -= CollapseAllRecordsRecursivly;
			AssociatedObject.ExpandAllButton.Click -= ExpandAllRecordsRecursivly;
		}
		#endregion

		#region Private Methods
		/// <summary>Initializes the event handlers for checked event of expand and collapse buttons. </summary>
		/// <param name="sender">The sender (The difference explorer view).</param>
		/// <param name="e">Event arguments.</param>
		private void AssociatedObject_Initialized(object sender, System.EventArgs e)
		{
			AssociatedObject.CollapseAllButton.Click += CollapseAllRecordsRecursivly;
			AssociatedObject.ExpandAllButton.Click += ExpandAllRecordsRecursivly;
		}

		/// <summary>Expands all records in the comparison data grid and uncheck the collapse button.</summary>
		/// <param name="sender">The sender (Expand button).</param>
		/// <param name="args">Event arguments.</param>
		private void ExpandAllRecordsRecursivly(object sender, RoutedEventArgs args)
		{
			AssociatedObject.xamComparison.Records.ExpandAll(true);
		}

		/// <summary>Collapses all records in the comparison grid and uncheck the Expand button.</summary>
		/// <param name="sender">The sender (Collapse button).</param>
		/// <param name="args">Event arguments.</param>
		private void CollapseAllRecordsRecursivly(object sender, RoutedEventArgs args)
		{
			AssociatedObject.xamComparison.Records.CollapseAll(true);
		}
		#endregion
	}
}
